@@ -17,10 +17,9 @@ pub mod patterns {
     pub mod callbacks;
     pub mod option;
     pub mod primitives;
-    pub mod service_generated;
-    pub mod service_manual;
+    pub mod result;
+    pub mod service;
     pub mod slice;
-    pub mod success_enum;
 }
 pub mod types;
 
@@ -82,12 +81,8 @@ interoptopus::inventory!(
         patterns::primitives::pattern_ffi_bool,
         patterns::api_entry::pattern_my_api_init_v1,
         patterns::api_guard::pattern_api_guard,
-        patterns::service_generated::simple_service_ext_util,
         patterns::callbacks::pattern_callback_1
     ],
     [types::ExtraType<f32>],
-    [
-        patterns::service_manual::my_service_pattern_context,
-        patterns::service_generated::simple_service_pattern
-    ]
+    [patterns::service::SimpleService]
 );
